@@ -1,17 +1,19 @@
-from typing import Any, Dict, List
-from typing_extensions import Literal
-
 import json
+from typing import Any, Dict, List
+
 import pendulum
 from pendulum.datetime import DateTime
 from swimlane import Swimlane
 from swimlane.core.resources.record import Record
+from typing_extensions import Literal
 
 _LEVELS = ["debug", "info", "warning", "error", "critical"]
 
 
 class UseCaseOutcome:
-    def __init__(self, sl: Swimlane, app_name: str, integration_name: str, **default_fields) -> None:
+    def __init__(
+        self, sl: Swimlane, app_name: str, integration_name: str, **default_fields
+    ) -> None:
         self.sl = sl
         self.app_name = app_name
         self.integration_name = integration_name
@@ -51,7 +53,13 @@ class UseCaseOutcome:
             **self.arbitrary_record_fields,
             "raw_metrics": json.dumps(self.metrics),
             "raw_logs": json.dumps(self.logs),
-            "raw_fields_changed": json.dumps([field_changed for field_changed in self.fields_changed if "timestamp" in field_changed]),
+            "raw_fields_changed": json.dumps(
+                [
+                    field_changed
+                    for field_changed in self.fields_changed
+                    if "timestamp" in field_changed
+                ]
+            ),
             "auto_close": "YES" if auto_closed else "NO",
             "start_time": self.use_case_started.to_iso8601_string().replace(":", "-"),
             "end_time": et.to_iso8601_string().replace(":", "-"),
@@ -75,7 +83,14 @@ class UseCaseOutcome:
                 f"level must be one of the following : {','.join(_LEVELS)}"
             )
 
-        self.logs.append({**kwargs, "level": level, **self.default_fields, "timestamp": pendulum.now().to_iso8601_string()})
+        self.logs.append(
+            {
+                **kwargs,
+                "level": level,
+                **self.default_fields,
+                "timestamp": pendulum.now().to_iso8601_string(),
+            }
+        )
 
     def metric(self, metric_name: str, metric_value: Any):
         self.metrics.append({"metric_name": metric_name, "metric_value": metric_value})
@@ -98,9 +113,7 @@ class UseCaseOutcome:
 
     def _normalise_logs(self):
         # returns the list of logs that are passed in, with each dict containing the same keys. Required for UI widget
-        keys = set([
-            key for item in self.logs for key in item.keys()
-        ])
+        keys = set([key for item in self.logs for key in item.keys()])
 
         for log in self.logs:
             for key in keys:
